@@ -4,3 +4,9 @@ from ._where import later, locally, remotely  # noqa
 
 __version__ = get_versions()["version"]
 del get_versions
+
+
+def load_ipython_extension(ip):
+    from ._magic import AfarMagic
+
+    ip.register_magics(AfarMagic)
