@@ -2,7 +2,6 @@ import builtins
 import sys
 from io import StringIO
 from threading import Lock, local
-from time import sleep
 
 from ._reprs import display_repr
 
@@ -75,24 +74,14 @@ def print_outputs_async(out, stderr_future, repr_future, stdout_future):
     """
     try:
         stdout_val = stdout_future.result()
-        out.clear_output()
-        count = 0
-        while out.outputs:
-            # See: https://github.com/jupyter-widgets/ipywidgets/issues/3260
-            count += 1
-            if count == 100:  # 0.5 seconds
-                # This doesn't appear to always clear correctly in JupyterLab.
-                # I don't know why.  I'm still investigating.
-                out.outputs = type(out.outputs)()  # is this safe?
-                break
-            sleep(0.005)
+        # out.clear_output()  # Not thread-safe!
+        # See: https://github.com/jupyter-widgets/ipywidgets/issues/3260
+        out.outputs = type(out.outputs)()  # current workaround
         if stdout_val:
             out.append_stdout(stdout_val)
-
         stderr_val = stderr_future.result()
         if stderr_val:
             out.append_stderr(stderr_val)
-
         if repr_future is not None:
             repr_val = repr_future.result()
             if repr_val is not None:
